from shampoo import Hologram
import numpy as np

hologram_path = '../../data/USAF_test.tif'
h = Hologram.from_tif(hologram_path)

n_z_slices = 5
propagation_distances = np.linspace(0.03585, 0.03785, n_z_slices)

# Allocate some memory for the reconstructed intensity images
intensities = np.zeros((n_z_slices, h.hologram.shape[0], h.hologram.shape[1]),
                       dtype=np.complex128)

# Loop over all propagation distances
for i, distance in enumerate(propagation_distances):

    # Reconstruct at each distance
    wave = h.reconstruct(distance)

    # Save the result to the data cube
    intensities[i, ...] = wave.intensity

# Measure standard deviation within each intensity image
std_intensities = np.std(intensities, axis=(1, 2))

# Initialize a figure object
import matplotlib.pyplot as plt

fig, ax = plt.subplots()
ax.plot(propagation_distances, std_intensities, 'o-')
ax.axvline(propagation_distances[np.argmax(std_intensities)], ls='--',
           label='Best propagation distance')
ax.set(xlabel='Propagation distance', ylabel='std( Intensity )')
ax.legend()
plt.show()